#
# spec file for package python-json5
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#
%if 0%{?suse_version} > 1500
%bcond_without libalternatives
%else
%bcond_with libalternatives
%endif

%{?sle15_python_module_pythons}
Name:           python-json5
Version:        0.9.28
Release:        1.5
Summary:        A Python implementation of the JSON5 data format
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/dpranke/pyjson5
Source:         https://github.com/dpranke/pyjson5/archive/v%{version}.tar.gz#/pyjson5-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros >= 20210929
%if %{with libalternatives}
Requires:       alts
BuildRequires:  alts
%else
Requires(post): update-alternatives
Requires(postun): update-alternatives
%endif
BuildArch:      noarch
%python_subpackages

%description
A Python implementation of the JSON5 data format.

JSON5 extends the JSON data interchange format to make it
slightly more usable as a configuration language:

  * JavaScript-style comments (both single and multi-line) are legal.
  * Object keys may be unquoted if they are legal ECMAScript identifiers
  * Objects and arrays may end with trailing commas.
  * Strings can be single-quoted, and multi-line string literals are allowed.

%prep
%setup -q -n pyjson5-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/pyjson5
%python_expand rm -rf %{buildroot}%{$python_sitelib}/tests
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%pre
# If libalternatives is used: Removing old update-alternatives entries.
%python_libalternatives_reset_alternative pyjson5

%post
%python_install_alternative pyjson5

%postun
%python_uninstall_alternative pyjson5

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/pyjson5
%{python_sitelib}/json5
%{python_sitelib}/json5-%{version}.dist-info

%changelog
* Wed Nov 13 2024 Dirk Müller <dmueller@suse.com>
- update to 0.9.28:
  * Fix GitHub CI to install uv so ./run tests works properly.
  * Mark Python3.13 as supported in package metadata.
  * Update dev package dependencies
  * Fix typo in //README.md
  * GitHub issue #82 Add support for the strict parameter to
    load()/loads().
  * Significantly rework the infra and the run script to be
    contemporary.
* Mon Apr 15 2024 Dirk Müller <dmueller@suse.com>
- update to 0.9.25:
  * Explicitly specify the directory to use for the package in
    pyproject.toml.
* Mon Mar 25 2024 Dirk Müller <dmueller@suse.com>
- update to 0.9.24:
  * drop python2
  * switch to pyproject.toml
  * add typing
  * format with ruff
* Mon Nov 27 2023 Dirk Müller <dmueller@suse.com>
- update to 0.9.14:
  * Handle `+Infinity` as well as `-Infinity` and `Infinity`.
* Sun Mar 26 2023 Dirk Müller <dmueller@suse.com>
- update to 0.9.13:
  * Remove a field from one of the JSON benchmark files to
    reduce confusion in Chromium.
  * No code changes.
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- update to 0.9.12:
  * fix dump error on python 2
  * fix GitHub actions
* Sat Sep 24 2022 Dirk Müller <dmueller@suse.com>
- update to 0.9.10:
  * Updated the //README.md to be clear that parsing arbitrary JS
    code may not work.
  * Fixed serialization for objects that subclass `int` or `float`:
    Previously we would use the objects __str__ implementation, but
    that might result in an illegal JSON5 value if the object had
    customized __str__ to return something illegal. Instead,
    we follow the lead of the `JSON` module and call `int.__repr__`
    or `float.__repr__` directly.
  * While I was at it, I added tests for dumps(-inf) and dumps(nan)
    when those were supposed to be disallowed by `allow_nan=False`.
* Sun May 29 2022 Dirk Müller <dmueller@suse.com>
- update to 0.9.8:
  * Fixed error reporting in some cases due to how parsing was handling
    nested rules in the grammar - previously the reported location for
    the error could be far away from the point where it actually happened.
  * Fixed behavior of `default` fn in `dump` and `dumps`. Previously
    we didn't require the function to return a string, and so we could
    end up returning something that wasn't actually valid. This change
    now matches the behavior in the `json` module.
* Tue Oct  5 2021 Stefan Schubert <schubi@suse.de>
- Added BuildRequires:  alts
* Fri Oct  1 2021 Stefan Schubert <schubi@suse.de>
- Use libalternatives instead of update-alternatives.
* Tue Jun 22 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.9.6
  * Bump development status classifier to 5 - Production/Stable
  * Bump the tested Python versions to 2.7, 3.8 and 3.9
  * GitHub issue #46 Fix incorrect serialization of custom subtypes
  * Make it possible to run the tests if hypothesis isn't installed.
  * Miscellaneous non-source cleanups in the repo
* Mon May 25 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Thu Apr 16 2020 pgajdos@suse.com
- version update to 0.9.4
  * v0.9.4 (2020-03-26)
  * [GitHub pull #38](https://github.com/dpranke/pyjson5/pull/38)
    Fix from fredrik@fornwall.net for dumps() crashing when passed
    an empty string as a key in an object.
  * v0.9.3 (2020-03-17)
  * [GitHub pull #35](https://github.com/dpranke/pyjson5/pull/35)
    Fix from pastelmind@ for dump() not passing the right args to dumps().
  * Fix from p.skouzos@novafutur.com to remove the tests directory from
    the setup call, making the package a bit smaller.
  * v0.9.2 (2020-03-02)
  * [GitHub pull #34](https://github.com/dpranke/pyjson5/pull/34)
    Fix from roosephu@ for a badly formatted nested list.
  * v0.9.1 (2020-02-09)
  * [GitHub issue #33](https://github.com/dpranke/pyjson5/issues/33):
    Fix stray trailing comma when dumping an object with an invalid key.
  * v0.9.0 (2020-01-30)
  * [GitHub issue #29](https://github.com/dpranke/pyjson5/issues/29):
    Fix an issue where objects keys that started with a reserved
    word were incorrectly quoted.
  * [GitHub issue #30](https://github.com/dpranke/pyjson5/issues/30):
    Fix an issue where dumps() incorrectly thought a data structure
    was cyclic in some cases.
  * [GitHub issue #32](https://github.com/dpranke/pyjson5/issues/32):
    Allow for non-string keys in dicts passed to ``dump()``/``dumps()``.
    Add an ``allow_duplicate_keys=False`` to prevent possible
    ill-formed JSON that might result.
* Mon Jul 29 2019 Todd R <toddrme2178@gmail.com>
- Initial version
